#include <iostream>
#include <experimental/filesystem>

#include "hi_common.h"
#include "zlog.h"

#include "isp/eb3516_video.h"
#include "nnie/eb3516_nnie.h"

int main(int argc, char** argv) {
    int result = 0;
    std::error_code file_error;

    zlog_category_t *log = nullptr;

    // init log and check log.conf
    result = zlog_init("log.conf");
    if (result) {
        std::cout << "zlog init failed! Please check log.conf!\n";
        return (-1);
    }

    // get log cat for main to print
    log = zlog_get_category("cat");
    if (!log) {
        std::cout << "Main get log failed!\n";
        return (-2);
    }
    zlog_info(log, "Init zlog Sucessfully");

    if (!std::experimental::filesystem::remove_all("log", file_error)) {
        zlog_warn(log, "Can't Remove Last Logs FOR %s", file_error.message().c_str());
    }

    if (!std::experimental::filesystem::create_directory("log", file_error)) {
        zlog_warn(log, "Can't Create log dir FOR %s", file_error.message().c_str());
    }

    // eb3516VideoInit();
    // eb3516VideoStart();
    eb3516Yolov3Init("./coco_yolov3_detect.wk", "./dog_bike_car_416x416.bgr");
    eb3516Yolov3Exit();

    zlog_fini();

    return 0;
}
